import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'dart:math';


/// Flutter code sample for [Draggable].

void main() => runApp(const TindBookApp());
class TindBookApp extends StatelessWidget {
  const TindBookApp({super.key});

  @override
  Widget build(BuildContext context) {
    return ChangeNotifierProvider(
      create: (context) => TindBookState(),
      child: MaterialApp(
        title: 'Tind Book',
        theme: ThemeData(
          useMaterial3: true,
          colorScheme: ColorScheme.fromSeed(seedColor:Color.fromARGB(255, Random().nextInt(255), Random().nextInt(255), Random().nextInt(255))),
        ),
        home: Builder(
          builder: (context) {
            return Directionality(
              textDirection: TextDirection.ltr, // or TextDirection.rtl
              child: Scaffold(
                appBar: AppBar(title: const Text('Draggable Sample')),
                body: MyHomePage(),
              ),
            );
          },
        ),
      ),
    );
  }
}


class TindBookState extends ChangeNotifier {

}

class TindBook extends StatefulWidget {
  const TindBook({super.key});

  @override
  State<TindBook> createState() => _TindBookApp();
}

class _TindBookApp extends State<TindBook> {
  bool acceptedData = false;
  double dragDistance = 0.0;

  @override
  Widget build(BuildContext context) {
    return LayoutBuilder(
      builder: (context, constraints) {
        double containerWidth = constraints.maxWidth / 3; // Adjust as needed
        double containerHeight = constraints.maxHeight; // Adjust as needed

        return Row(
          mainAxisAlignment: MainAxisAlignment.spaceEvenly,
          children: <Widget>[
            DragTarget<bool>(
              builder: (
                BuildContext context,
                List<dynamic> accepted,
                List<dynamic> rejected,
              ) {
                return Container(
                  height: containerHeight,
                  width: containerWidth,
                  color: Colors.cyan,
                  child: Center(
                    child: Text('Value is updated to: $acceptedData'),
                  ),
                );
              },
              onAccept: (bool data) {
                setState(() {
                  acceptedData = data;
                  acceptedData = false;
                });
              },
            ),
            GestureDetector(
              onHorizontalDragUpdate: (details) {
                setState(() {
                  print('selected: ${details.primaryDelta}');
                  dragDistance = details.primaryDelta!;
                });
              },
              child: Draggable<bool>(
                // Data is the value this Draggable stores.
                data: true,
                feedback: AnimatedContainer(
                  duration: Duration(milliseconds: 4), // No animation for feedback
                  transform: Matrix4.rotationZ(dragDistance*50),
                  child: Container(
                    color: Colors.deepOrange,
                    height: containerHeight,
                    width: containerWidth,
                    child: const Icon(Icons.directions_run),
                  ),
                ),
                childWhenDragging: Container(
                  height: containerHeight,
                  width: containerWidth,
                  color: Colors.pinkAccent,
                  child: const Center(
                    child: Text('Child When Dragging'),
                  ),
                ),
                child: Container(
                  height: containerHeight,
                  width: containerWidth,
                  color: const Color.fromARGB(255, 255, 89, 89),
                  child: const Center(
                    child: Text('Draggable'),
                  ),
                ),
              ),
            ),
            DragTarget<bool>(
              builder: (
                BuildContext context,
                List<dynamic> accepted,
                List<dynamic> rejected,
              ) {
                return Container(
                  height: containerHeight,
                  width: containerWidth,
                  color: Colors.cyan,
                  child: Center(
                    child: Text('Value is updated to: $acceptedData'),
                  ),
                );
              },
              onAccept: (bool data) {
                setState(() {
                  acceptedData = data;
                });
              },
            ),
          ],
        );
      },
    );
  }
}

// test 




class FavoritePage extends StatelessWidget {

  
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      
      body: Column(children: [

        Text('Test'),

        
      ],)



    );
  }
}


class MyHomePage extends StatefulWidget {
  @override
  State<MyHomePage> createState() => _MyHomePageState();
}

class _MyHomePageState extends State<MyHomePage> {

  var selectedIndex = 0;
  @override
  Widget build(BuildContext context) {
    Widget page;
    switch (selectedIndex) {
      case 0:
        page = TindBook();
        break;
      case 1:
        page = FavoritePage();
        break;
      case 2:
        page = Placeholder();
        break;
      default:
        throw UnimplementedError('no widget for $selectedIndex');
    }

    return LayoutBuilder(
      builder: (context,constraints) {
        return Scaffold(
          body: Row(
            children: [
              SafeArea(
                child: NavigationRail(
                  extended: constraints.maxWidth>=600,
                  destinations: [
                    NavigationRailDestination(
                      icon: Icon(Icons.home),
                      label: Text('Home'),
                    ),
                    NavigationRailDestination(
                      icon: Icon(Icons.swipe),
                      label: Text('Swipe'),
                    ),
                     NavigationRailDestination(
                      icon: Icon(Icons.info),
                      label: Text('About'),
                      ),
                  ],
                  selectedIndex: selectedIndex,
                  onDestinationSelected: (value) {
                    print('selected: $value');
                    setState(() {
                      selectedIndex = value;
                    });
                  },
                ),
              ),
              Expanded(
                child: Container(
                  color: Theme.of(context).colorScheme.primaryContainer,
                  child: page,
                ),
              ),
            ],
          ),
        );
      }
    );
  }
}